@@ -1,3 +1,4 @@
+require "tmpdir"
 require "helper"
 require "thor/actions"
 
@@ -25,7 +26,7 @@ describe Thor::Actions::Directory do
 
   def exists_and_identical?(source_path, destination_path)
     %w(config.rb README).each do |file|
-      source      = File.join(source_root, source_path, file)
+      source = File.join(source_root, source_path, file)
       destination = File.join(destination_root, destination_path, file)
 
       expect(File.exist?(destination)).to be true
@@ -146,6 +147,24 @@ describe Thor::Actions::Directory do
       content = invoke!("app{1}")
       expect(content).to match(%r{create  app\{1\}/README})
     end
+
+    context "windows temp directories", :if => windows? do
+      let(:spec_dir) { File.join(@temp_dir, "spec") }
+
+      before(:each) do
+        @temp_dir = Dir.mktmpdir("thor")
+        Dir.mkdir(spec_dir)
+        File.new(File.join(spec_dir, "spec_helper.rb"), "w").close
+      end
+
+      after(:each) { FileUtils.rm_rf(@temp_dir) }
+      it "works with windows temp dir" do
+        invoke! spec_dir, "specs"
+        file = File.join(destination_root, "specs")
+        expect(File.exist?(file)).to be true
+        expect(File.directory?(file)).to be true
+      end
+    end
   end
 
   describe "#revoke!" do
